#!/usr/bin/env python
#-*- coding:utf-8 -*-
#===============================================================================
#  Copyright (C) 2010 Schaefer & Tobies SuC GmbH.
#  Author: Markus Grimm <mgr@schaefer-tobies.de>
#
#  This file is part of Pyontapi.
#
#  Pyontapi is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyontapi is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Pyontapi.  If not, see <http://www.gnu.org/licenses/>.
#
#===============================================================================

""" Command-Line tool for setting up Pyontapi """

import os
import sys

def setup():
    """ Ask for settings and write it to local_settings.py ."""
    basedir = os.path.join(
        os.path.dirname(__file__), os.pardir, os.pardir, os.pardir
    )
    try:
        __import__('schtob.pyontapi')
    except ImportError:
        sys.path.append(basedir)
    
    from schtob.pyontapi import constants, util
    from schtob.pyontapi.settings import NA_CONFIG
    
    basedir = util.get_folder()
    
    print "Welcome to Pyontapi's setup tool"
    
    transport_type = get_value("Specify HTTP transport type.", 'Transport Type',
                               NA_CONFIG.get('transport_type', constants.HTTP), 
                               constants.TRANSPORT_TYPES)
    login_style = get_value("Specify ONTAPI Login Style.", 'Login Style', 
                            NA_CONFIG.get('style', constants.LOGIN),
                            constants.STYLES)
    user = NA_CONFIG.get('user', 'root')
    password = NA_CONFIG.get('password', '')
    if login_style == constants.LOGIN:
        import getpass
        user = get_value_no_validate('Specify the username.', 'Username', user)
        print "\nSpecify password."
        password = getpass.getpass('Password: ')
    
    NA_CONFIG.update({
        'user': user,
        'password': password,
        'style': login_style,
        'trasport_type': transport_type,
    })
    write_config(basedir, NA_CONFIG)
    print "\nSaved config to local_settings.py"

def write_config(basedir, config):
    """ write ``config`` dict into file. """
    handle = file(
        os.path.join(basedir, 'local_settings.py'), 
        'w'
    )
    handle.write('''#!/usr/bin/env python
#-*- coding:utf-8 -*-
#===============================================================================
#  Copyright (C) 2010 Schaefer & Tobies SuC GmbH.
#  Author: Markus Grimm <mgr@schaefer-tobies.de>
#
#  This file is part of Pyontapi.
#
#  Pyontapi is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyontapi is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Pyontapi.  If not, see <http://www.gnu.org/licenses/>.
#
#===============================================================================

""" local settings file. define ``NA_CONFIG`` here. """

NA_CONFIG = {
%s
}

''' % '\n'.join([
        '    %s: %s,' % (repr(key), repr(val)) for key, val in config.items()
    ]))
    handle.close()

def get_value_no_validate(question, field_name, default):
    """ get value for ``field_name``. No validation """
    print '\n' + question
    input_question = '%s (Default: %s): ' % (field_name, default)
    while True:
        value = raw_input(input_question) or default
        if value:
            break
        else:
            print "Value %s is not valid" % value
    return value

def get_value(question, field_name, default, possible_values):
    """ get value for ``field_name``. """
    print '\n' + question + ' Possible: ' + ', '.join(possible_values) + '.'
    input_question = '%s (Default: %s): ' % (field_name, default)
    value = default
    while True:
        value = raw_input(input_question) or default
        if value in possible_values:
            break
        else:
            print "Value %s is not valid" % value
    return value

if __name__ == '__main__':
    setup()